# pymath

Launch the python repl imported with all of the functions from `math` and `itertools` along with some extra math related functions.

## Installation

**Note**: `~/.local/bin` should be in your `PATH` for `--user` installs.

```shell
pip install --user pymath2
```
